@@ -19,10 +19,10 @@ echo "Index file: $index_file";
 cat << 'EOF' > $index_file
 <html>
 <head>
-<title>Man pages for the Open Lighting Project</title>
+<title>Man pages for the Open Lighting Architecture</title>
 </head>
 <body>
-<h1>Man pages for the <a href="http://openlighting.org">Open Lighting Project</a></h1>
+<h1>Man pages for the <a href="https://openlighting.org/ola/">Open Lighting Architecture</a></h1>
 <ul>
 EOF
 
@@ -35,7 +35,7 @@ for man_file in *.1; do
   output_file=$output_dir/man1/$man_file.html;
   man2html -r $man_file -M ../index.html | sed 1,2d > $output_file;
   chmod a+r $output_file;
-  echo "<li><a href='./man1/$man_file.html'>$man_file</a></li>" >> $index_file
+  echo "<li><a href='./man1/$man_file.html'>$man_file</a> - `grep "\.SH NAME" $man_file -A 1 | tail -n 1 | sed -e 's/\\\-/-/g'`</li>" >> $index_file
 done
 
 cat << 'EOF' >> $index_file
